

[Back to main file](README.md)

Required libraries/software for Tableau-Hyper-Management
========================================================

| Name                                                         | Version              | Released                                                                                                     | Type                 | Importance                     | Platform                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | No.  |
| ------------------------------------------------------------ | -------------------- | ------------------------------------------------------------------------------------------------------------ | -------------------- | ------------------------------ |   |   | ---- |
| [Double Commander](https://doublecmd.sourceforge.io/)        | 0.9.8                | [2019-02-01](https://sourceforge.net/projects/doublecmd/files/DC%20for%20Windows%2064%20bit/)                | File Manager         | Optional (File Manager)        | [Windows 32-bit](http://sourceforge.net/projects/doublecmd/files/DC%20for%20Windows%2032%20bit/Double%20Commander%200.9.8%20beta/doublecmd-0.9.8.i386-win32.exe/download) and [Windows 32-bit ZIP](http://sourceforge.net/projects/doublecmd/files/DC%20for%20Windows%2032%20bit/Double%20Commander%200.9.8%20beta/doublecmd-0.9.8.i386-win32.zip/download) and [Windows 64-bit](http://sourceforge.net/projects/doublecmd/files/DC%20for%20Windows%2064%20bit/Double%20Commander%200.9.8%20beta/doublecmd-0.9.8.x86_64-win64.exe/download) and [Windows 64-bit ZIP](http://sourceforge.net/projects/doublecmd/files/DC%20for%20Windows%2064%20bit/Double%20Commander%200.9.8%20beta/doublecmd-0.9.8.x86_64-win64.zip/download) | Double Commander is an open source multi-platform two-panel orthodox file manager that is inspired by the Microsoft Windows-only Total Commander.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        | #1   |
| [Git](https://git-scm.com/)                                  | 2.26.2               | [2020-04-20](https://github.com/git-for-windows/git/releases/)                                               | Version Control      | Required (Versioning)          | [Windows 32-bit](https://github.com/git-for-windows/git/releases/download/v2.26.2.windows.1/Git-2.26.2-32-bit.exe) and [Windows 32-bit Portable](https://github.com/git-for-windows/git/releases/download/v2.26.2.windows.1/PortableGit-2.26.2-32-bit.7z.exe) and [Windows 64-bit](https://github.com/git-for-windows/git/releases/download/v2.26.2.windows.1/Git-2.26.2-64-bit.exe) and [Windows 64-bit Portable](https://github.com/git-for-windows/git/releases/download/v2.26.2.windows.1/PortableGit-2.26.2-64-bit.7z.exe)                                                                                                                                                                                                 | Git is a version control system for tracking changes in computer files and coordinating work on those files among multiple people. It is primarily used for source code management in software development, but it can be used to keep track of changes in any set of files. As a distributed revision control system, it is aimed at speed, data integrity, and support for distributed, non-linear workflows.                                                                                                                                                                                                                                                                                                                                                                                                                                                                          | #2   |
| [MarkDown Editor](https://markdownedit.com/)                 | 1.35.0               | [2018-10-07](https://github.com/mike-ward/Markdown-Edit/releases)                                            | MD editor            | Optional (Documentation)       | [Windows 32-bit](https://github.com/mike-ward/Markdown-Edit/releases/download/v1.35/MarkdownEditSetup.msi) and [Windows 32-bit Portable](https://github.com/mike-ward/Markdown-Edit/releases/download/v1.35/MarkdownEdit.zip)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   | Free. Cross-platform. Open source. A developer platform for building all your apps.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | #3   |
| [Mozilla Firefox](https://www.mozilla.org/en-US/firefox/)    | 76.0.1               | [2020-05-08](https://wiki.mozilla.org/Release_Management/Calendar)                                           | Internet Browser     | Optional (Internet Browser)    | [Windows 32-bit](https://download-installer.cdn.mozilla.net/pub/firefox/releases/76.0.1/win32-EME-free/en-US/Firefox%20Setup%2076.0.1.exe) and [Windows 64-bit](https://download-installer.cdn.mozilla.net/pub/firefox/releases/76.0.1/win64-EME-free/en-US/Firefox%20Setup%2076.0.1.exe)                                                                                                                                                                                                                                                                                                                                                                                                                                       | Mozilla Firefox (or simply Firefox) is a free and open-source web browser developed by The Mozilla Foundation and its subsidiary, Mozilla Corporation. Firefox is available for Windows, macOS, Linux, BSD, illumos and Solaris operating systems. Its sibling, Firefox for Android, is also available. Firefox uses the Gecko layout engine to render web pages, which implements current and anticipated web standards. In 2017, Firefox began incorporating new technology under the code name Quantum to promote parallelism and a more intuitive user interface. An additional version, Firefox for iOS, was released on November 12, 2015. Due to platform restrictions, it uses the WebKit layout engine instead of Gecko, as with all other iOS web browsers.                                                                                                                    | #4   |
| [Notepad++](https://notepad-plus-plus.org/)                  | 7.8.6                | [2020-04-20](https://notepad-plus-plus.org/download/)                                                        | Advanced Text Editor | Optional Advanced Text Editor  | [Windows 32-bit](https://notepad-plus-plus.org/repository/7.x/7.8.6/npp.7.8.6.Installer.exe) and [Windows 32-bit Portable](https://notepad-plus-plus.org/repository/7.x/7.8.6/npp.7.8.6.bin.7z) and [Windows 64-bit](https://notepad-plus-plus.org/repository/7.x/7.8.6/npp.7.8.6.Installer.x64.exe) and [Windows 64-bit Portable](https://notepad-plus-plus.org/repository/7.x/7.8.6/npp.7.8.6.bin.x64.7z)                                                                                                                                                                                                                                                                                                                     | Notepad++ is a free (as in `free speech` and also as in `free beer`) source code editor and Notepad replacement that supports several languages. Running in the MS Windows environment, its use is governed by GPL License. Based on the powerful editing component Scintilla, Notepad++ is written in C++ and uses pure Win32 API and STL which ensures a higher execution speed and smaller program size. By optimizing as many routines as possible without losing user friendliness, Notepad++ is trying to reduce the world carbon dioxide emissions. When using less CPU power, the PC can throttle down and reduce power consumption, resulting in a greener environment.                                                                                                                                                                                                         | #5   |
| [PyCharm 2020.1.x](https://www.jetbrains.com/pycharm/)       | 2020.1.1.201.7223.92 | [2020-05-07](https://www.jetbrains.com/pycharm/download/other.html)                                          | IDE                  | Optional (Python IDE)          | [Community Windows](https://download.jetbrains.com/python/pycharm-community-2020.1.1.exe) and [Community Windows with Anaconda](https://download.jetbrains.com/python/pycharm-community-anaconda-2020.1.1.exe) and [Professional Windows](https://download.jetbrains.com/python/pycharm-professional-2020.1.1.exe) and [Professional Windows with Anaconda](https://download.jetbrains.com/python/pycharm-professional-anaconda-2020.1.1.exe)                                                                                                                                                                                                                                                                                   | The Python IDE for Professional Developers                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | #6   |
| [Python 3.8.x](https://www.python.org/)                      | 3.8.2                | [2020-02-25](https://docs.python.org/3.8/whatsnew/changelog.html)                                            | Scriptign Engine     | Required (Programming)         | [Windows 32-bit](https://www.python.org/ftp/python/3.8.2/python-3.8.2.exe) and [Windows 32-bit Portable](https://www.python.org/ftp/python/3.8.2/python-3.8.2-embed-win32.zip) and [Windows 64-bit](https://www.python.org/ftp/python/3.8.2/python-3.8.2-amd64.exe) and [Windows 64-bit Portable](https://www.python.org/ftp/python/3.8.2/python-3.8.2-embed-amd64.zip) and [Windows Help File](https://www.python.org/ftp/python/3.8.2/python381.chm)                                                                                                                                                                                                                                                                          | Python is a programming language that lets you work quickly and integrate systems more effectively.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      | #7   |
| [Sourcetree 3.3.x](https://www.sourcetreeapp.com/)           | 3.3.8                | [2020-01-08](https://product-downloads.atlassian.com/software/sourcetree/windows/ga/ReleaseNotes_3.3.6.html) | Git Client           | Optional (visual git client)   | [Windows 64-bit](https://product-downloads.atlassian.com/software/sourcetree/windows/ga/SourceTreeSetup-3.3.8.exe)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              | Sourcetree simplifies how you interact with your Git repositories so you can focus on coding. Visualize and manage your repositories through Sourcetree's simple Git GUI.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                | #8   |
| [Tableau Desktop Desktop 2019.3.x](https://www.tableau.com/) | 2019.3.7             | [2020-04-29](https://www.tableau.com/support/releases)                                                       | Visualization Tool   | Optional (used for Dashboards) | [Windows 64-bit](https://downloads.tableau.com/esdalt/2019.3.7/TableauDesktop-64bit-2019-3-7.exe)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               | Tableau has a mapping functionality, and is able to plot latitude and longitude coordinates and connect to spatial files like Esri Shapefiles, KML, and GeoJSON to display custom geography. The built-in geocoding allows for administrative places (country, state/province, county/district), postal codes, US Congressional Districts, US CBSA/MSA, Area Codes, Airports, and European Union statistical areas (NUTS codes) to be mapped automatically. You can group geographies to create custom territories or use custom geocoding to extend existing geographic roles in the product. There are five ways to access their products: Desktop (both professional and personal editions), Server, Online (which scales to support thousands of users), Reader, and Public, with the last two free to use. Vizable, a consumer data visualization mobile app, was released in 2015. | #9   |
| [Tree](http://mama.indstate.edu/users/ice/tree)              | 1.5.2.2              | [2009-02-09](http://mama.indstate.edu/users/ice/tree/changes.html)                                           | Utility              | Optional                       | [Windows 32-bit](https://sourceforge.net/projects/gnuwin32/files/tree/1.5.2.2/tree-1.5.2.2-bin.zip/download)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    | Tree is a recursive directory listing program that produces a depth indented listing of files, which is colorized ala dircolors if the LS_COLORS environment variable is set and output is to tty.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       | #10  |
